@@ -179,9 +179,7 @@ class QRFResults(ImputerResults):
                 for i, variable in enumerate(self.imputed_variables):
                     var_start_time = time.time()
 
-                    if (
-                        not quantiles
-                    ):  # Only log per-variable when not processing multiple quantiles
+                    if not quantiles:
                         self.logger.info(
                             f"[{i+1}/{len(self.imputed_variables)}] Predicting for '{variable}'"
                         )
@@ -224,12 +222,17 @@ class QRFResults(ImputerResults):
                             f"  ✓ {variable} predicted in {var_time:.2f}s ({len(imputed_values)} samples)"
                         )
 
+                    self.logger.info(
+                        f"QRF predictions completed for {variable} imputed variable"
+                    )
+
                 imputations[q] = imputed_df
 
-            self.logger.info(
-                f"QRF predictions completed for {len(X_test)} samples"
-            )
-            return imputations
+            qs = imputations.keys()
+            if len(qs) < 2:
+                q = list(qs)[0]
+
+            return imputations if quantiles else imputations[q]
 
         except Exception as e:
             self.logger.error(f"Error during QRF prediction: {str(e)}")
@@ -377,9 +380,6 @@ class QRF(Imputer):
                             self.logger.info(
                                 f"  Features: {len(current_predictors)} predictors"
                             )
-                            self.logger.info(
-                                f"  Training data shape: {X_train[current_predictors + [variable]].shape}"
-                            )
                             self.logger.info(
                                 f"  Memory usage: {self._get_memory_usage_info()}"
                             )
@@ -508,15 +508,11 @@ class QRF(Imputer):
                         self.logger.info(
                             f"  Features: {len(current_predictors)} predictors"
                         )
-                        self.logger.info(
-                            f"  Training data shape: {X_train[current_predictors + [variable]].shape}"
-                        )
                         self.logger.info(
                             f"  Memory usage: {self._get_memory_usage_info()}"
                         )
 
                         # Create and fit model
-                        # Note: X_train is already preprocessed by base class
                         model = _QRFModel(seed=self.seed, logger=self.logger)
 
                         try:
@@ -610,9 +606,6 @@ class QRF(Imputer):
             self.logger.info(
                 f"  Features: {len(current_predictors)} predictors"
             )
-            self.logger.info(
-                f"  Training data shape: {X_train[current_predictors + [variable]].shape}"
-            )
             self.logger.info(
                 f"  Memory usage: {self._get_memory_usage_info()}"
             )
